RetryStrategy

Struct RetryStrategy 

pub struct RetryStrategy { /* private fields */ }
Retry strategy executor.

Implementations

Source

impl RetryStrategy

pub fn new(config: RetryConfig) -> Self

Create a new retry strategy with the given configuration.

pub async fn execute<F, Fut, T>(&self, f: F) -> AixResult<T>
where F: FnMut() -> Fut, Fut: Future<Output = AixResult<T>>,

Execute an operation with retry logic.

Arguments
  • f - A closure that returns a Future yielding an AixResult
Returns

The result of the operation, or the last error if all retries fail

pub fn config(&self) -> &RetryConfig

Get a reference to the configuration.

pub fn config_mut(&mut self) -> &mut RetryConfig

Get a mutable reference to the configuration.