pub fn from_string<S>(id: S, text: S) -> TokenStreamExpand description
Create a stream from a string that yields character by character.
pub fn from_string<S>(id: S, text: S) -> TokenStreamCreate a stream from a string that yields character by character.